name = "Dharun L"
dob = "17-10-2009"
email = "t96halaivar@gmail.com"
location = "Salem, Tamilnadu, India"
github = "https://github.com/thalaivar96"

def profile():
    return {
        "Name": name,
        "Date of Birth": dob,
        "Email": email,
        "Location": location,
        "GitHub": github
    }
